summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorElizabeth Fischer <rpf2116@columbia.edu>2019-06-18 13:32:00 -0400
committerTamara Dahlgren <35777542+tldahlgren@users.noreply.github.com>2019-06-18 10:32:00 -0700
commitf886c7e59dd08afc8a92e208a559a4e120683304 (patch)
tree95891c6e77f264d91651903573b2366865b3d29e /lib
parent003f670ef9b2c98a1958dba04ea0679492a32e74 (diff)
downloadspack-f886c7e59dd08afc8a92e208a559a4e120683304.tar.gz
spack-f886c7e59dd08afc8a92e208a559a4e120683304.tar.bz2
spack-f886c7e59dd08afc8a92e208a559a4e120683304.tar.xz
spack-f886c7e59dd08afc8a92e208a559a4e120683304.zip
Rename build.out to build.txt (#11749)
Rename build.out to build.txt; makes it easier when people post log files to the Spack mailing list.
Diffstat (limited to 'lib')
-rw-r--r--lib/spack/spack/directory_layout.py2
-rw-r--r--lib/spack/spack/package.py6
-rw-r--r--lib/spack/spack/test/cmd/install.py2
3 files changed, 5 insertions, 5 deletions
diff --git a/lib/spack/spack/directory_layout.py b/lib/spack/spack/directory_layout.py
index b90daaecad..4f77e618ce 100644
--- a/lib/spack/spack/directory_layout.py
+++ b/lib/spack/spack/directory_layout.py
@@ -190,7 +190,7 @@ class YamlDirectoryLayout(DirectoryLayout):
self.metadata_dir = '.spack'
self.spec_file_name = 'spec.yaml'
self.extension_file_name = 'extensions.yaml'
- self.build_log_name = 'build.out' # build log.
+ self.build_log_name = 'build.txt' # build log.
self.build_env_name = 'build.env' # build environment
self.packages_dir = 'repos' # archive of package.py files
diff --git a/lib/spack/spack/test/cmd/install.py b/lib/spack/spack/test/cmd/install.py
index 6393626fa1..3cc6f4a0bf 100644
--- a/lib/spack/spack/test/cmd/install.py
+++ b/lib/spack/spack/test/cmd/install.py
@@ -125,7 +125,7 @@ def test_package_output(tmpdir, capsys, install_mockery, mock_fetch):
pkg = spec.package
pkg.do_install(verbose=True)
- log_file = os.path.join(spec.prefix, '.spack', 'build.out')
+ log_file = os.path.join(spec.prefix, '.spack', 'build.txt')
with open(log_file) as f:
out = f.read()
diff --git a/lib/spack/spack/package.py b/lib/spack/spack/package.py
index fd580376df..3ae46792b5 100644
--- a/lib/spack/spack/package.py
+++ b/lib/spack/spack/package.py
@@ -433,7 +433,7 @@ class PackageBase(with_metaclass(PackageMeta, PackageViewMixin, object)):
#: List of glob expressions. Each expression must either be
#: absolute or relative to the package source path.
#: Matching artifacts found at the end of the build process will
#: be copied in the same directory tree as build.env and build.out.
archive_files = []
#
@@ -786,7 +786,7 @@ class PackageBase(with_metaclass(PackageMeta, PackageViewMixin, object)):
@property
def log_path(self):
- return os.path.join(self.stage.path, 'spack-build.out')
+ return os.path.join(self.stage.path, 'spack-build.txt')
def _make_fetcher(self):
# Construct a composite fetcher that always contains at least
@@ -1814,7 +1814,7 @@ class PackageBase(with_metaclass(PackageMeta, PackageViewMixin, object)):
if self.installed:
return spack.store.layout.build_log_path(self.spec)
else:
- return os.path.join(self.stage.path, 'spack-build.out')
+ return self.log_path
@classmethod
def inject_flags(cls, name, flags):
@@ -433,7 +433,7 @@ class PackageBase(with_metaclass(PackageMeta, PackageViewMixin, object)):
#: absolute or relative to the package source path.
#: Matching artifacts found at the end of the build process will
- #: be copied in the same directory tree as build.env and build.out.
+ #: be copied in the same directory tree as build.env and build.txt.
archive_files = []
#